@@ -1,8 +1,11 @@
+// features
 #![feature(box_syntax)]
 #![feature(map_first_last)]
 #![feature(arbitrary_enum_discriminant)]
-// #![deny(missing_docs)]
+// lints
+#![deny(missing_docs)]
 #![allow(clippy::needless_return)]
+// documentation
 #![doc = include_str!("../Readme.md")]
 pub mod command;
 mod errors;
